summaryrefslogtreecommitdiff
path: root/libexec
diff options
context:
space:
mode:
authordholland <dholland@NetBSD.org>2013-01-22 09:39:11 +0000
committerdholland <dholland@NetBSD.org>2013-01-22 09:39:11 +0000
commitd8eae7d25b49bac06cbad931bc3978073c028d65 (patch)
tree52fd0c429caf914f7378c1ccb0ce2a1d28b30a9e /libexec
parent445568dc95e8e9c89e42d485d795140cae260244 (diff)
Stuff UFS_ in front of a few of ufs's symbols to reduce namespace
pollution. Specifically: ROOTINO -> UFS_ROOTINO WINO -> UFS_WINO NXADDR -> UFS_NXADDR NDADDR -> UFS_NDADDR NIADDR -> UFS_NIADDR MAXSYMLINKLEN -> UFS_MAXSYMLINKLEN MAXSYMLINKLEN_UFS[12] -> UFS[12]_MAXSYMLINKLEN (for consistency) Sort out ext2fs's misuse of NDADDR and NIADDR; fortunately, these have the same values in ext2fs and ffs. No functional change intended.
Diffstat (limited to 'libexec')
-rw-r--r--libexec/lfs_cleanerd/coalesce.c4
-rw-r--r--libexec/lfs_cleanerd/lfs_cleanerd.c10
2 files changed, 7 insertions, 7 deletions
diff --git a/libexec/lfs_cleanerd/coalesce.c b/libexec/lfs_cleanerd/coalesce.c
index 1929a86bd7d..8f3ad9499c7 100644
--- a/libexec/lfs_cleanerd/coalesce.c
+++ b/libexec/lfs_cleanerd/coalesce.c
@@ -1,4 +1,4 @@
-/* $NetBSD: coalesce.c,v 1.19 2012/01/02 21:35:17 perseant Exp $ */
+/* $NetBSD: coalesce.c,v 1.20 2013/01/22 09:39:11 dholland Exp $ */
/*-
* Copyright (c) 2002, 2005 The NetBSD Foundation, Inc.
@@ -164,7 +164,7 @@ clean_inode(struct clfs *fs, ino_t ino)
onb = nb = lblkno(fs, dip->di_size);
/* XXX for now, don't do any file small enough to have fragments */
- if (nb < NDADDR) {
+ if (nb < UFS_NDADDR) {
free(dip);
return COALESCE_TOOSMALL;
}
diff --git a/libexec/lfs_cleanerd/lfs_cleanerd.c b/libexec/lfs_cleanerd/lfs_cleanerd.c
index 826c396d5af..4dd58e67f93 100644
--- a/libexec/lfs_cleanerd/lfs_cleanerd.c
+++ b/libexec/lfs_cleanerd/lfs_cleanerd.c
@@ -1,4 +1,4 @@
-/* $NetBSD: lfs_cleanerd.c,v 1.31 2012/04/16 10:48:27 joerg Exp $ */
+/* $NetBSD: lfs_cleanerd.c,v 1.32 2013/01/22 09:39:11 dholland Exp $ */
/*-
* Copyright (c) 2005 The NetBSD Foundation, Inc.
@@ -342,9 +342,9 @@ lfs_ientry(IFILE **ifpp, struct clfs *fs, ino_t ino, struct ubuf **bpp)
#ifdef TEST_PATTERN
/*
* Check ROOTINO for file data. The assumption is that we are running
* the "twofiles" test with the rest of the filesystem empty. Files
- * created by "twofiles" match the test pattern, but ROOTINO and the
+ * created by "twofiles" match the test pattern, but UFS_ROOTINO and the
* executable itself (assumed to be inode 3) should not match.
*/
static void
@@ -950,7 +950,7 @@ static off_t
check_hidden_cost(struct clfs *fs, BLOCK_INFO *bip, int bic, off_t *ifc)
{
int start;
- struct indir in[NIADDR + 1];
+ struct indir in[UFS_NIADDR + 1];
int num;
int i, j, ebic;
BLOCK_INFO *ebip;
@@ -974,7 +974,7 @@ check_hidden_cost(struct clfs *fs, BLOCK_INFO *bip, int bic, off_t *ifc)
}
if (bip[i].bi_lbn == LFS_UNUSED_LBN)
continue;
- if (bip[i].bi_lbn < NDADDR)
+ if (bip[i].bi_lbn < UFS_NDADDR)
continue;
ufs_getlbns((struct lfs *)fs, NULL, (daddr_t)bip[i].bi_lbn, in, &num);
@@ -342,9 +342,9 @@ lfs_ientry(IFILE **ifpp, struct clfs *fs, ino_t ino, struct ubuf **bpp)
#ifdef TEST_PATTERN
/*
- * Check ROOTINO for file data. The assumption is that we are running
+ * Check UFS_ROOTINO for file data. The assumption is that we are running
* the "twofiles" test with the rest of the filesystem empty. Files